==> haskell-cassava-megaparsec-2.0.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 2.0.0
id: cassava-megaparsec-2.0.0-7ukGmUbd06NHbTlrCDg3O0
key: cassava-megaparsec-2.0.0-7ukGmUbd06NHbTlrCDg3O0
license: MIT
maintainer: Mark Karpov <markkarpov92@gmail.org>
author: Mark Karpov <markkarpov92@gmail.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 7ce3f136820e0ba51f437e29c9012ab7
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cassava-megaparsec-2.0.0
hs-libraries: HScassava-megaparsec-2.0.0-7ukGmUbd06NHbTlrCDg3O0
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-6ml3A1iZljH474S2ij9pz4
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.0.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 2.0.0
id: cassava-megaparsec-2.0.0-BSNRlZgflSlD0BHu6HblGa
key: cassava-megaparsec-2.0.0-BSNRlZgflSlD0BHu6HblGa
license: MIT
maintainer: Mark Karpov <markkarpov92@gmail.org>
author: Mark Karpov <markkarpov92@gmail.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 8f05049d50cc6e9b53c37326d80add88
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cassava-megaparsec-2.0.0
hs-libraries: HScassava-megaparsec-2.0.0-BSNRlZgflSlD0BHu6HblGa
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-F6QsLHKZGsxKUqm3l0b5hY
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
